# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/vpc/v1/gateway_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.vpc.v1 import gateway_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_gateway__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/vpc/v1/gateway_service.proto',
  package='yandex.cloud.vpc.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)yandex/cloud/vpc/v1/gateway_service.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a!yandex/cloud/vpc/v1/gateway.proto\"5\n\x11GetGatewayRequest\x12 \n\ngateway_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListGatewaysRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"_\n\x14ListGatewaysResponse\x12.\n\x08gateways\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.vpc.v1.Gateway\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"~\n\x1cListGatewayOperationsRequest\x12 \n\ngateway_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListGatewayOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x19\n\x17SharedEgressGatewaySpec\"\xaa\x03\n\x14\x43reateGatewayRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8e\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x35.yandex.cloud.vpc.v1.CreateGatewayRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12R\n\x1ashared_egress_gateway_spec\x18\x05 \x01(\x0b\x32,.yandex.cloud.vpc.v1.SharedEgressGatewaySpecH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07gateway\"+\n\x15\x43reateGatewayMetadata\x12\x12\n\ngateway_id\x18\x01 \x01(\t\"\xdc\x03\n\x14UpdateGatewayRequest\x12 \n\ngateway_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8e\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x35.yandex.cloud.vpc.v1.UpdateGatewayRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12R\n\x1ashared_egress_gateway_spec\x18\x06 \x01(\x0b\x32,.yandex.cloud.vpc.v1.SharedEgressGatewaySpecH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07gateway\"+\n\x15UpdateGatewayMetadata\x12\x12\n\ngateway_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteGatewayRequest\x12 \n\ngateway_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteGatewayMetadata\x12\x12\n\ngateway_id\x18\x01 \x01(\t\"c\n\x12MoveGatewayRequest\x12 \n\ngateway_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13MoveGatewayMetadata\x12\x12\n\ngateway_id\x18\x01 \x01(\t2\xc0\x08\n\x0eGatewayService\x12r\n\x03Get\x12&.yandex.cloud.vpc.v1.GetGatewayRequest\x1a\x1c.yandex.cloud.vpc.v1.Gateway\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/vpc/v1/gateways/{gateway_id}\x12u\n\x04List\x12(.yandex.cloud.vpc.v1.ListGatewaysRequest\x1a).yandex.cloud.vpc.v1.ListGatewaysResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/vpc/v1/gateways\x12\x97\x01\n\x06\x43reate\x12).yandex.cloud.vpc.v1.CreateGatewayRequest\x1a!.yandex.cloud.operation.Operation\"?\x82\xd3\xe4\x93\x02\x15\"\x10/vpc/v1/gateways:\x01*\xb2\xd2* \n\x15\x43reateGatewayMetadata\x12\x07Gateway\x12\xa4\x01\n\x06Update\x12).yandex.cloud.vpc.v1.UpdateGatewayRequest\x1a!.yandex.cloud.operation.Operation\"L\x82\xd3\xe4\x93\x02\"2\x1d/vpc/v1/gateways/{gateway_id}:\x01*\xb2\xd2* \n\x15UpdateGatewayMetadata\x12\x07Gateway\x12\xaf\x01\n\x06\x44\x65lete\x12).yandex.cloud.vpc.v1.DeleteGatewayRequest\x1a!.yandex.cloud.operation.Operation\"W\x82\xd3\xe4\x93\x02\x1f*\x1d/vpc/v1/gateways/{gateway_id}\xb2\xd2*.\n\x15\x44\x65leteGatewayMetadata\x12\x15google.protobuf.Empty\x12\xa9\x01\n\x0eListOperations\x12\x31.yandex.cloud.vpc.v1.ListGatewayOperationsRequest\x1a\x32.yandex.cloud.vpc.v1.ListGatewayOperationsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/vpc/v1/gateways/{gateway_id}/operations\x12\xa3\x01\n\x04Move\x12\'.yandex.cloud.vpc.v1.MoveGatewayRequest\x1a!.yandex.cloud.operation.Operation\"O\x82\xd3\xe4\x93\x02\'\"\"/vpc/v1/gateways/{gateway_id}:move:\x01*\xb2\xd2*\x1e\n\x13MoveGatewayMetadata\x12\x07GatewayBV\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_vpc_dot_v1_dot_gateway__pb2.DESCRIPTOR,])




_GETGATEWAYREQUEST = _descriptor.Descriptor(
  name='GetGatewayRequest',
  full_name='yandex.cloud.vpc.v1.GetGatewayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateway_id', full_name='yandex.cloud.vpc.v1.GetGatewayRequest.gateway_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=323,
)


_LISTGATEWAYSREQUEST = _descriptor.Descriptor(
  name='ListGatewaysRequest',
  full_name='yandex.cloud.vpc.v1.ListGatewaysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.vpc.v1.ListGatewaysRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.vpc.v1.ListGatewaysRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.vpc.v1.ListGatewaysRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.vpc.v1.ListGatewaysRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=470,
)


_LISTGATEWAYSRESPONSE = _descriptor.Descriptor(
  name='ListGatewaysResponse',
  full_name='yandex.cloud.vpc.v1.ListGatewaysResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateways', full_name='yandex.cloud.vpc.v1.ListGatewaysResponse.gateways', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.vpc.v1.ListGatewaysResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=472,
  serialized_end=567,
)


_LISTGATEWAYOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListGatewayOperationsRequest',
  full_name='yandex.cloud.vpc.v1.ListGatewayOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateway_id', full_name='yandex.cloud.vpc.v1.ListGatewayOperationsRequest.gateway_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.vpc.v1.ListGatewayOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.vpc.v1.ListGatewayOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=695,
)


_LISTGATEWAYOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListGatewayOperationsResponse',
  full_name='yandex.cloud.vpc.v1.ListGatewayOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.vpc.v1.ListGatewayOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.vpc.v1.ListGatewayOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=808,
)


_SHAREDEGRESSGATEWAYSPEC = _descriptor.Descriptor(
  name='SharedEgressGatewaySpec',
  full_name='yandex.cloud.vpc.v1.SharedEgressGatewaySpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=810,
  serialized_end=835,
)


_CREATEGATEWAYREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.vpc.v1.CreateGatewayRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.vpc.v1.CreateGatewayRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.vpc.v1.CreateGatewayRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1208,
  serialized_end=1253,
)

_CREATEGATEWAYREQUEST = _descriptor.Descriptor(
  name='CreateGatewayRequest',
  full_name='yandex.cloud.vpc.v1.CreateGatewayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.vpc.v1.CreateGatewayRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.vpc.v1.CreateGatewayRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.vpc.v1.CreateGatewayRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.vpc.v1.CreateGatewayRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared_egress_gateway_spec', full_name='yandex.cloud.vpc.v1.CreateGatewayRequest.shared_egress_gateway_spec', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEGATEWAYREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='gateway', full_name='yandex.cloud.vpc.v1.CreateGatewayRequest.gateway',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=838,
  serialized_end=1264,
)


_CREATEGATEWAYMETADATA = _descriptor.Descriptor(
  name='CreateGatewayMetadata',
  full_name='yandex.cloud.vpc.v1.CreateGatewayMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateway_id', full_name='yandex.cloud.vpc.v1.CreateGatewayMetadata.gateway_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1266,
  serialized_end=1309,
)


_UPDATEGATEWAYREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.vpc.v1.UpdateGatewayRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.vpc.v1.UpdateGatewayRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.vpc.v1.UpdateGatewayRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1208,
  serialized_end=1253,
)

_UPDATEGATEWAYREQUEST = _descriptor.Descriptor(
  name='UpdateGatewayRequest',
  full_name='yandex.cloud.vpc.v1.UpdateGatewayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateway_id', full_name='yandex.cloud.vpc.v1.UpdateGatewayRequest.gateway_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.vpc.v1.UpdateGatewayRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.vpc.v1.UpdateGatewayRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.vpc.v1.UpdateGatewayRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.vpc.v1.UpdateGatewayRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared_egress_gateway_spec', full_name='yandex.cloud.vpc.v1.UpdateGatewayRequest.shared_egress_gateway_spec', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEGATEWAYREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='gateway', full_name='yandex.cloud.vpc.v1.UpdateGatewayRequest.gateway',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1312,
  serialized_end=1788,
)


_UPDATEGATEWAYMETADATA = _descriptor.Descriptor(
  name='UpdateGatewayMetadata',
  full_name='yandex.cloud.vpc.v1.UpdateGatewayMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateway_id', full_name='yandex.cloud.vpc.v1.UpdateGatewayMetadata.gateway_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1790,
  serialized_end=1833,
)


_DELETEGATEWAYREQUEST = _descriptor.Descriptor(
  name='DeleteGatewayRequest',
  full_name='yandex.cloud.vpc.v1.DeleteGatewayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateway_id', full_name='yandex.cloud.vpc.v1.DeleteGatewayRequest.gateway_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1835,
  serialized_end=1891,
)


_DELETEGATEWAYMETADATA = _descriptor.Descriptor(
  name='DeleteGatewayMetadata',
  full_name='yandex.cloud.vpc.v1.DeleteGatewayMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateway_id', full_name='yandex.cloud.vpc.v1.DeleteGatewayMetadata.gateway_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1893,
  serialized_end=1936,
)


_MOVEGATEWAYREQUEST = _descriptor.Descriptor(
  name='MoveGatewayRequest',
  full_name='yandex.cloud.vpc.v1.MoveGatewayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateway_id', full_name='yandex.cloud.vpc.v1.MoveGatewayRequest.gateway_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.vpc.v1.MoveGatewayRequest.destination_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1938,
  serialized_end=2037,
)


_MOVEGATEWAYMETADATA = _descriptor.Descriptor(
  name='MoveGatewayMetadata',
  full_name='yandex.cloud.vpc.v1.MoveGatewayMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateway_id', full_name='yandex.cloud.vpc.v1.MoveGatewayMetadata.gateway_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2039,
  serialized_end=2080,
)

_LISTGATEWAYSRESPONSE.fields_by_name['gateways'].message_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_gateway__pb2._GATEWAY
_LISTGATEWAYOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
_CREATEGATEWAYREQUEST_LABELSENTRY.containing_type = _CREATEGATEWAYREQUEST
_CREATEGATEWAYREQUEST.fields_by_name['labels'].message_type = _CREATEGATEWAYREQUEST_LABELSENTRY
_CREATEGATEWAYREQUEST.fields_by_name['shared_egress_gateway_spec'].message_type = _SHAREDEGRESSGATEWAYSPEC
_CREATEGATEWAYREQUEST.oneofs_by_name['gateway'].fields.append(
  _CREATEGATEWAYREQUEST.fields_by_name['shared_egress_gateway_spec'])
_CREATEGATEWAYREQUEST.fields_by_name['shared_egress_gateway_spec'].containing_oneof = _CREATEGATEWAYREQUEST.oneofs_by_name['gateway']
_UPDATEGATEWAYREQUEST_LABELSENTRY.containing_type = _UPDATEGATEWAYREQUEST
_UPDATEGATEWAYREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEGATEWAYREQUEST.fields_by_name['labels'].message_type = _UPDATEGATEWAYREQUEST_LABELSENTRY
_UPDATEGATEWAYREQUEST.fields_by_name['shared_egress_gateway_spec'].message_type = _SHAREDEGRESSGATEWAYSPEC
_UPDATEGATEWAYREQUEST.oneofs_by_name['gateway'].fields.append(
  _UPDATEGATEWAYREQUEST.fields_by_name['shared_egress_gateway_spec'])
_UPDATEGATEWAYREQUEST.fields_by_name['shared_egress_gateway_spec'].containing_oneof = _UPDATEGATEWAYREQUEST.oneofs_by_name['gateway']
DESCRIPTOR.message_types_by_name['GetGatewayRequest'] = _GETGATEWAYREQUEST
DESCRIPTOR.message_types_by_name['ListGatewaysRequest'] = _LISTGATEWAYSREQUEST
DESCRIPTOR.message_types_by_name['ListGatewaysResponse'] = _LISTGATEWAYSRESPONSE
DESCRIPTOR.message_types_by_name['ListGatewayOperationsRequest'] = _LISTGATEWAYOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListGatewayOperationsResponse'] = _LISTGATEWAYOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['SharedEgressGatewaySpec'] = _SHAREDEGRESSGATEWAYSPEC
DESCRIPTOR.message_types_by_name['CreateGatewayRequest'] = _CREATEGATEWAYREQUEST
DESCRIPTOR.message_types_by_name['CreateGatewayMetadata'] = _CREATEGATEWAYMETADATA
DESCRIPTOR.message_types_by_name['UpdateGatewayRequest'] = _UPDATEGATEWAYREQUEST
DESCRIPTOR.message_types_by_name['UpdateGatewayMetadata'] = _UPDATEGATEWAYMETADATA
DESCRIPTOR.message_types_by_name['DeleteGatewayRequest'] = _DELETEGATEWAYREQUEST
DESCRIPTOR.message_types_by_name['DeleteGatewayMetadata'] = _DELETEGATEWAYMETADATA
DESCRIPTOR.message_types_by_name['MoveGatewayRequest'] = _MOVEGATEWAYREQUEST
DESCRIPTOR.message_types_by_name['MoveGatewayMetadata'] = _MOVEGATEWAYMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetGatewayRequest = _reflection.GeneratedProtocolMessageType('GetGatewayRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETGATEWAYREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.GetGatewayRequest)
  })
_sym_db.RegisterMessage(GetGatewayRequest)

ListGatewaysRequest = _reflection.GeneratedProtocolMessageType('ListGatewaysRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTGATEWAYSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListGatewaysRequest)
  })
_sym_db.RegisterMessage(ListGatewaysRequest)

ListGatewaysResponse = _reflection.GeneratedProtocolMessageType('ListGatewaysResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTGATEWAYSRESPONSE,
  '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListGatewaysResponse)
  })
_sym_db.RegisterMessage(ListGatewaysResponse)

ListGatewayOperationsRequest = _reflection.GeneratedProtocolMessageType('ListGatewayOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTGATEWAYOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListGatewayOperationsRequest)
  })
_sym_db.RegisterMessage(ListGatewayOperationsRequest)

ListGatewayOperationsResponse = _reflection.GeneratedProtocolMessageType('ListGatewayOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTGATEWAYOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListGatewayOperationsResponse)
  })
_sym_db.RegisterMessage(ListGatewayOperationsResponse)

SharedEgressGatewaySpec = _reflection.GeneratedProtocolMessageType('SharedEgressGatewaySpec', (_message.Message,), {
  'DESCRIPTOR' : _SHAREDEGRESSGATEWAYSPEC,
  '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.SharedEgressGatewaySpec)
  })
_sym_db.RegisterMessage(SharedEgressGatewaySpec)

CreateGatewayRequest = _reflection.GeneratedProtocolMessageType('CreateGatewayRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEGATEWAYREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateGatewayRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEGATEWAYREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateGatewayRequest)
  })
_sym_db.RegisterMessage(CreateGatewayRequest)
_sym_db.RegisterMessage(CreateGatewayRequest.LabelsEntry)

CreateGatewayMetadata = _reflection.GeneratedProtocolMessageType('CreateGatewayMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEGATEWAYMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateGatewayMetadata)
  })
_sym_db.RegisterMessage(CreateGatewayMetadata)

UpdateGatewayRequest = _reflection.GeneratedProtocolMessageType('UpdateGatewayRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEGATEWAYREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateGatewayRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEGATEWAYREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateGatewayRequest)
  })
_sym_db.RegisterMessage(UpdateGatewayRequest)
_sym_db.RegisterMessage(UpdateGatewayRequest.LabelsEntry)

UpdateGatewayMetadata = _reflection.GeneratedProtocolMessageType('UpdateGatewayMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGATEWAYMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateGatewayMetadata)
  })
_sym_db.RegisterMessage(UpdateGatewayMetadata)

DeleteGatewayRequest = _reflection.GeneratedProtocolMessageType('DeleteGatewayRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEGATEWAYREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.DeleteGatewayRequest)
  })
_sym_db.RegisterMessage(DeleteGatewayRequest)

DeleteGatewayMetadata = _reflection.GeneratedProtocolMessageType('DeleteGatewayMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEGATEWAYMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.DeleteGatewayMetadata)
  })
_sym_db.RegisterMessage(DeleteGatewayMetadata)

MoveGatewayRequest = _reflection.GeneratedProtocolMessageType('MoveGatewayRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVEGATEWAYREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.MoveGatewayRequest)
  })
_sym_db.RegisterMessage(MoveGatewayRequest)

MoveGatewayMetadata = _reflection.GeneratedProtocolMessageType('MoveGatewayMetadata', (_message.Message,), {
  'DESCRIPTOR' : _MOVEGATEWAYMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.MoveGatewayMetadata)
  })
_sym_db.RegisterMessage(MoveGatewayMetadata)


DESCRIPTOR._options = None
_GETGATEWAYREQUEST.fields_by_name['gateway_id']._options = None
_LISTGATEWAYSREQUEST.fields_by_name['folder_id']._options = None
_LISTGATEWAYSREQUEST.fields_by_name['page_size']._options = None
_LISTGATEWAYSREQUEST.fields_by_name['page_token']._options = None
_LISTGATEWAYSREQUEST.fields_by_name['filter']._options = None
_LISTGATEWAYOPERATIONSREQUEST.fields_by_name['gateway_id']._options = None
_LISTGATEWAYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTGATEWAYOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_CREATEGATEWAYREQUEST_LABELSENTRY._options = None
_CREATEGATEWAYREQUEST.fields_by_name['folder_id']._options = None
_CREATEGATEWAYREQUEST.fields_by_name['name']._options = None
_CREATEGATEWAYREQUEST.fields_by_name['description']._options = None
_CREATEGATEWAYREQUEST.fields_by_name['labels']._options = None
_UPDATEGATEWAYREQUEST_LABELSENTRY._options = None
_UPDATEGATEWAYREQUEST.fields_by_name['gateway_id']._options = None
_UPDATEGATEWAYREQUEST.fields_by_name['name']._options = None
_UPDATEGATEWAYREQUEST.fields_by_name['description']._options = None
_UPDATEGATEWAYREQUEST.fields_by_name['labels']._options = None
_DELETEGATEWAYREQUEST.fields_by_name['gateway_id']._options = None
_MOVEGATEWAYREQUEST.fields_by_name['gateway_id']._options = None
_MOVEGATEWAYREQUEST.fields_by_name['destination_folder_id']._options = None

_GATEWAYSERVICE = _descriptor.ServiceDescriptor(
  name='GatewayService',
  full_name='yandex.cloud.vpc.v1.GatewayService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2083,
  serialized_end=3171,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.vpc.v1.GatewayService.Get',
    index=0,
    containing_service=None,
    input_type=_GETGATEWAYREQUEST,
    output_type=yandex_dot_cloud_dot_vpc_dot_v1_dot_gateway__pb2._GATEWAY,
    serialized_options=b'\202\323\344\223\002\037\022\035/vpc/v1/gateways/{gateway_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.vpc.v1.GatewayService.List',
    index=1,
    containing_service=None,
    input_type=_LISTGATEWAYSREQUEST,
    output_type=_LISTGATEWAYSRESPONSE,
    serialized_options=b'\202\323\344\223\002\022\022\020/vpc/v1/gateways',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.vpc.v1.GatewayService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEGATEWAYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\025\"\020/vpc/v1/gateways:\001*\262\322* \n\025CreateGatewayMetadata\022\007Gateway',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.vpc.v1.GatewayService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEGATEWAYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\"2\035/vpc/v1/gateways/{gateway_id}:\001*\262\322* \n\025UpdateGatewayMetadata\022\007Gateway',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.vpc.v1.GatewayService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEGATEWAYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\037*\035/vpc/v1/gateways/{gateway_id}\262\322*.\n\025DeleteGatewayMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.vpc.v1.GatewayService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTGATEWAYOPERATIONSREQUEST,
    output_type=_LISTGATEWAYOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002*\022(/vpc/v1/gateways/{gateway_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Move',
    full_name='yandex.cloud.vpc.v1.GatewayService.Move',
    index=6,
    containing_service=None,
    input_type=_MOVEGATEWAYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\'\"\"/vpc/v1/gateways/{gateway_id}:move:\001*\262\322*\036\n\023MoveGatewayMetadata\022\007Gateway',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GATEWAYSERVICE)

DESCRIPTOR.services_by_name['GatewayService'] = _GATEWAYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iot/devices/v1/registry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/iot/devices/v1/registry.proto',
  package='yandex.cloud.iot.devices.v1',
  syntax='proto3',
  serialized_options=b'\n\037yandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devices',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/iot/devices/v1/registry.proto\x12\x1byandex.cloud.iot.devices.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8c\x03\n\x08Registry\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x41\n\x06labels\x18\x06 \x03(\x0b\x32\x31.yandex.cloud.iot.devices.v1.Registry.LabelsEntry\x12<\n\x06status\x18\x07 \x01(\x0e\x32,.yandex.cloud.iot.devices.v1.Registry.Status\x12\x14\n\x0clog_group_id\x18\x08 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\"\x89\x01\n\x13RegistryCertificate\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\x12\x18\n\x10\x63\x65rtificate_data\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"E\n\x0b\x44\x65viceAlias\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x14\n\x0ctopic_prefix\x18\x02 \x01(\t\x12\r\n\x05\x61lias\x18\x03 \x01(\t\"c\n\x10RegistryPassword\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xca\x01\n\x10\x44\x61taStreamExport\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bregistry_id\x18\x03 \x01(\t\x12\x19\n\x11mqtt_topic_filter\x18\x04 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x05 \x01(\t\x12\x0e\n\x06stream\x18\x06 \x01(\t\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampBj\n\x1fyandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devicesb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_REGISTRY_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.iot.devices.v1.Registry.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=433,
  serialized_end=505,
)
_sym_db.RegisterEnumDescriptor(_REGISTRY_STATUS)


_REGISTRY_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.iot.devices.v1.Registry.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.iot.devices.v1.Registry.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.iot.devices.v1.Registry.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=431,
)

_REGISTRY = _descriptor.Descriptor(
  name='Registry',
  full_name='yandex.cloud.iot.devices.v1.Registry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.iot.devices.v1.Registry.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.iot.devices.v1.Registry.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.iot.devices.v1.Registry.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.iot.devices.v1.Registry.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.iot.devices.v1.Registry.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.iot.devices.v1.Registry.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.iot.devices.v1.Registry.status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.iot.devices.v1.Registry.log_group_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REGISTRY_LABELSENTRY, ],
  enum_types=[
    _REGISTRY_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=505,
)


_REGISTRYCERTIFICATE = _descriptor.Descriptor(
  name='RegistryCertificate',
  full_name='yandex.cloud.iot.devices.v1.RegistryCertificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='registry_id', full_name='yandex.cloud.iot.devices.v1.RegistryCertificate.registry_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerprint', full_name='yandex.cloud.iot.devices.v1.RegistryCertificate.fingerprint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate_data', full_name='yandex.cloud.iot.devices.v1.RegistryCertificate.certificate_data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.iot.devices.v1.RegistryCertificate.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=645,
)


_DEVICEALIAS = _descriptor.Descriptor(
  name='DeviceAlias',
  full_name='yandex.cloud.iot.devices.v1.DeviceAlias',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='yandex.cloud.iot.devices.v1.DeviceAlias.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_prefix', full_name='yandex.cloud.iot.devices.v1.DeviceAlias.topic_prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yandex.cloud.iot.devices.v1.DeviceAlias.alias', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=716,
)


_REGISTRYPASSWORD = _descriptor.Descriptor(
  name='RegistryPassword',
  full_name='yandex.cloud.iot.devices.v1.RegistryPassword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='registry_id', full_name='yandex.cloud.iot.devices.v1.RegistryPassword.registry_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.iot.devices.v1.RegistryPassword.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.iot.devices.v1.RegistryPassword.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=718,
  serialized_end=817,
)


_DATASTREAMEXPORT = _descriptor.Descriptor(
  name='DataStreamExport',
  full_name='yandex.cloud.iot.devices.v1.DataStreamExport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.iot.devices.v1.DataStreamExport.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.iot.devices.v1.DataStreamExport.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='registry_id', full_name='yandex.cloud.iot.devices.v1.DataStreamExport.registry_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mqtt_topic_filter', full_name='yandex.cloud.iot.devices.v1.DataStreamExport.mqtt_topic_filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='yandex.cloud.iot.devices.v1.DataStreamExport.database', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream', full_name='yandex.cloud.iot.devices.v1.DataStreamExport.stream', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iot.devices.v1.DataStreamExport.service_account_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.iot.devices.v1.DataStreamExport.created_at', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=820,
  serialized_end=1022,
)

_REGISTRY_LABELSENTRY.containing_type = _REGISTRY
_REGISTRY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REGISTRY.fields_by_name['labels'].message_type = _REGISTRY_LABELSENTRY
_REGISTRY.fields_by_name['status'].enum_type = _REGISTRY_STATUS
_REGISTRY_STATUS.containing_type = _REGISTRY
_REGISTRYCERTIFICATE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REGISTRYPASSWORD.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DATASTREAMEXPORT.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Registry'] = _REGISTRY
DESCRIPTOR.message_types_by_name['RegistryCertificate'] = _REGISTRYCERTIFICATE
DESCRIPTOR.message_types_by_name['DeviceAlias'] = _DEVICEALIAS
DESCRIPTOR.message_types_by_name['RegistryPassword'] = _REGISTRYPASSWORD
DESCRIPTOR.message_types_by_name['DataStreamExport'] = _DATASTREAMEXPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Registry = _reflection.GeneratedProtocolMessageType('Registry', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _REGISTRY_LABELSENTRY,
    '__module__' : 'yandex.cloud.iot.devices.v1.registry_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.Registry.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _REGISTRY,
  '__module__' : 'yandex.cloud.iot.devices.v1.registry_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.Registry)
  })
_sym_db.RegisterMessage(Registry)
_sym_db.RegisterMessage(Registry.LabelsEntry)

RegistryCertificate = _reflection.GeneratedProtocolMessageType('RegistryCertificate', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYCERTIFICATE,
  '__module__' : 'yandex.cloud.iot.devices.v1.registry_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.RegistryCertificate)
  })
_sym_db.RegisterMessage(RegistryCertificate)

DeviceAlias = _reflection.GeneratedProtocolMessageType('DeviceAlias', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEALIAS,
  '__module__' : 'yandex.cloud.iot.devices.v1.registry_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.DeviceAlias)
  })
_sym_db.RegisterMessage(DeviceAlias)

RegistryPassword = _reflection.GeneratedProtocolMessageType('RegistryPassword', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYPASSWORD,
  '__module__' : 'yandex.cloud.iot.devices.v1.registry_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.RegistryPassword)
  })
_sym_db.RegisterMessage(RegistryPassword)

DataStreamExport = _reflection.GeneratedProtocolMessageType('DataStreamExport', (_message.Message,), {
  'DESCRIPTOR' : _DATASTREAMEXPORT,
  '__module__' : 'yandex.cloud.iot.devices.v1.registry_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.DataStreamExport)
  })
_sym_db.RegisterMessage(DataStreamExport)


DESCRIPTOR._options = None
_REGISTRY_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/postgresql/v1/perf_diag_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.postgresql.v1 import perf_diag_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/postgresql/v1/perf_diag_service.proto',
  package='yandex.cloud.mdb.postgresql.v1',
  syntax='proto3',
  serialized_options=b'\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresql',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6yandex/cloud/mdb/postgresql/v1/perf_diag_service.proto\x12\x1eyandex.cloud.mdb.postgresql.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a.yandex/cloud/mdb/postgresql/v1/perf_diag.proto\"\xd7\x01\n\x18ListRawStatementsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12-\n\tfrom_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\tpage_size\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07<=10000\x12\x1d\n\npage_token\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\xda\x01\n\x1bListRawSessionStatesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12-\n\tfrom_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\tpage_size\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07<=10000\x12\x1d\n\npage_token\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"}\n\x1cListRawSessionStatesResponse\x12\x44\n\x0esession_states\x18\x01 \x03(\x0b\x32,.yandex.cloud.mdb.postgresql.v1.SessionState\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"x\n\x19ListRawStatementsResponse\x12\x42\n\nstatements\x18\x01 \x03(\x0b\x32..yandex.cloud.mdb.postgresql.v1.QueryStatement\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xbe\x02\n\x1dPerformanceDiagnosticsService\x12\x91\x01\n\x14ListRawSessionStates\x12;.yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesRequest\x1a<.yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesResponse\x12\x88\x01\n\x11ListRawStatements\x12\x38.yandex.cloud.mdb.postgresql.v1.ListRawStatementsRequest\x1a\x39.yandex.cloud.mdb.postgresql.v1.ListRawStatementsResponseBs\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresqlb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__pb2.DESCRIPTOR,])




_LISTRAWSTATEMENTSREQUEST = _descriptor.Descriptor(
  name='ListRawStatementsRequest',
  full_name='yandex.cloud.mdb.postgresql.v1.ListRawStatementsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.postgresql.v1.ListRawStatementsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_time', full_name='yandex.cloud.mdb.postgresql.v1.ListRawStatementsRequest.from_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_time', full_name='yandex.cloud.mdb.postgresql.v1.ListRawStatementsRequest.to_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.postgresql.v1.ListRawStatementsRequest.page_size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\007<=10000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.postgresql.v1.ListRawStatementsRequest.page_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=418,
)


_LISTRAWSESSIONSTATESREQUEST = _descriptor.Descriptor(
  name='ListRawSessionStatesRequest',
  full_name='yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_time', full_name='yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesRequest.from_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_time', full_name='yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesRequest.to_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesRequest.page_size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\007<=10000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesRequest.page_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=639,
)


_LISTRAWSESSIONSTATESRESPONSE = _descriptor.Descriptor(
  name='ListRawSessionStatesResponse',
  full_name='yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_states', full_name='yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesResponse.session_states', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=766,
)


_LISTRAWSTATEMENTSRESPONSE = _descriptor.Descriptor(
  name='ListRawStatementsResponse',
  full_name='yandex.cloud.mdb.postgresql.v1.ListRawStatementsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statements', full_name='yandex.cloud.mdb.postgresql.v1.ListRawStatementsResponse.statements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.postgresql.v1.ListRawStatementsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=768,
  serialized_end=888,
)

_LISTRAWSTATEMENTSREQUEST.fields_by_name['from_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTRAWSTATEMENTSREQUEST.fields_by_name['to_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTRAWSESSIONSTATESREQUEST.fields_by_name['from_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTRAWSESSIONSTATESREQUEST.fields_by_name['to_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTRAWSESSIONSTATESRESPONSE.fields_by_name['session_states'].message_type = yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__pb2._SESSIONSTATE
_LISTRAWSTATEMENTSRESPONSE.fields_by_name['statements'].message_type = yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__pb2._QUERYSTATEMENT
DESCRIPTOR.message_types_by_name['ListRawStatementsRequest'] = _LISTRAWSTATEMENTSREQUEST
DESCRIPTOR.message_types_by_name['ListRawSessionStatesRequest'] = _LISTRAWSESSIONSTATESREQUEST
DESCRIPTOR.message_types_by_name['ListRawSessionStatesResponse'] = _LISTRAWSESSIONSTATESRESPONSE
DESCRIPTOR.message_types_by_name['ListRawStatementsResponse'] = _LISTRAWSTATEMENTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListRawStatementsRequest = _reflection.GeneratedProtocolMessageType('ListRawStatementsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRAWSTATEMENTSREQUEST,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.ListRawStatementsRequest)
  })
_sym_db.RegisterMessage(ListRawStatementsRequest)

ListRawSessionStatesRequest = _reflection.GeneratedProtocolMessageType('ListRawSessionStatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRAWSESSIONSTATESREQUEST,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesRequest)
  })
_sym_db.RegisterMessage(ListRawSessionStatesRequest)

ListRawSessionStatesResponse = _reflection.GeneratedProtocolMessageType('ListRawSessionStatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRAWSESSIONSTATESRESPONSE,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesResponse)
  })
_sym_db.RegisterMessage(ListRawSessionStatesResponse)

ListRawStatementsResponse = _reflection.GeneratedProtocolMessageType('ListRawStatementsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRAWSTATEMENTSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.ListRawStatementsResponse)
  })
_sym_db.RegisterMessage(ListRawStatementsResponse)


DESCRIPTOR._options = None
_LISTRAWSTATEMENTSREQUEST.fields_by_name['cluster_id']._options = None
_LISTRAWSTATEMENTSREQUEST.fields_by_name['page_size']._options = None
_LISTRAWSTATEMENTSREQUEST.fields_by_name['page_token']._options = None
_LISTRAWSESSIONSTATESREQUEST.fields_by_name['cluster_id']._options = None
_LISTRAWSESSIONSTATESREQUEST.fields_by_name['page_size']._options = None
_LISTRAWSESSIONSTATESREQUEST.fields_by_name['page_token']._options = None

_PERFORMANCEDIAGNOSTICSSERVICE = _descriptor.ServiceDescriptor(
  name='PerformanceDiagnosticsService',
  full_name='yandex.cloud.mdb.postgresql.v1.PerformanceDiagnosticsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=891,
  serialized_end=1209,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListRawSessionStates',
    full_name='yandex.cloud.mdb.postgresql.v1.PerformanceDiagnosticsService.ListRawSessionStates',
    index=0,
    containing_service=None,
    input_type=_LISTRAWSESSIONSTATESREQUEST,
    output_type=_LISTRAWSESSIONSTATESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRawStatements',
    full_name='yandex.cloud.mdb.postgresql.v1.PerformanceDiagnosticsService.ListRawStatements',
    index=1,
    containing_service=None,
    input_type=_LISTRAWSTATEMENTSREQUEST,
    output_type=_LISTRAWSTATEMENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PERFORMANCEDIAGNOSTICSSERVICE)

DESCRIPTOR.services_by_name['PerformanceDiagnosticsService'] = _PERFORMANCEDIAGNOSTICSSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/trail_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/agent/v1/trail_service.proto',
  package='yandex.cloud.loadtesting.agent.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5yandex/cloud/loadtesting/agent/v1/trail_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1cgoogle/api/annotations.proto\"\x94\x01\n\x12\x43reateTrailRequest\x12\x1b\n\x13\x63ompute_instance_id\x18\x01 \x01(\t\x12\x36\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32(.yandex.cloud.loadtesting.agent.v1.Trail\x12\x0e\n\x06job_id\x18\x03 \x01(\t\x12\x19\n\x11\x61gent_instance_id\x18\x04 \x01(\t\"\xfc\x04\n\x05Trail\x12\x0f\n\x07overall\x18\x01 \x01(\x03\x12\x0f\n\x07\x63\x61se_id\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\t\x12\r\n\x05reqps\x18\x04 \x01(\x03\x12\r\n\x05resps\x18\x05 \x01(\x03\x12\x0e\n\x06\x65xpect\x18\x06 \x01(\x01\x12\r\n\x05input\x18\x07 \x01(\x03\x12\x0e\n\x06output\x18\x08 \x01(\x03\x12\x14\n\x0c\x63onnect_time\x18\t \x01(\x01\x12\x11\n\tsend_time\x18\n \x01(\x01\x12\x0f\n\x07latency\x18\x0b \x01(\x01\x12\x14\n\x0creceive_time\x18\x0c \x01(\x01\x12\x0f\n\x07threads\x18\r \x01(\x03\x12\x0b\n\x03q50\x18\x0e \x01(\x01\x12\x0b\n\x03q75\x18\x0f \x01(\x01\x12\x0b\n\x03q80\x18\x10 \x01(\x01\x12\x0b\n\x03q85\x18\x11 \x01(\x01\x12\x0b\n\x03q90\x18\x12 \x01(\x01\x12\x0b\n\x03q95\x18\x13 \x01(\x01\x12\x0b\n\x03q98\x18\x14 \x01(\x01\x12\x0b\n\x03q99\x18\x15 \x01(\x01\x12\x0c\n\x04q100\x18\x16 \x01(\x01\x12\x42\n\nhttp_codes\x18\x17 \x03(\x0b\x32..yandex.cloud.loadtesting.agent.v1.Trail.Codes\x12\x41\n\tnet_codes\x18\x18 \x03(\x0b\x32..yandex.cloud.loadtesting.agent.v1.Trail.Codes\x12J\n\x0etime_intervals\x18\x19 \x03(\x0b\x32\x32.yandex.cloud.loadtesting.agent.v1.Trail.Intervals\x1a$\n\x05\x43odes\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x1a&\n\tIntervals\x12\n\n\x02to\x18\x01 \x01(\x01\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\"5\n\x13\x43reateTrailResponse\x12\x10\n\x08trail_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x03\x32\xb1\x01\n\x0cTrailService\x12\xa0\x01\n\x06\x43reate\x12\x35.yandex.cloud.loadtesting.agent.v1.CreateTrailRequest\x1a\x36.yandex.cloud.loadtesting.agent.v1.CreateTrailResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/loadtesting/agent/v1/trails:\x01*Bt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CREATETRAILREQUEST = _descriptor.Descriptor(
  name='CreateTrailRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='compute_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailRequest.compute_instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailRequest.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailRequest.job_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailRequest.agent_instance_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=271,
)


_TRAIL_CODES = _descriptor.Descriptor(
  name='Codes',
  full_name='yandex.cloud.loadtesting.agent.v1.Trail.Codes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='yandex.cloud.loadtesting.agent.v1.Trail.Codes.code', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='yandex.cloud.loadtesting.agent.v1.Trail.Codes.count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=870,
)

_TRAIL_INTERVALS = _descriptor.Descriptor(
  name='Intervals',
  full_name='yandex.cloud.loadtesting.agent.v1.Trail.Intervals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='to', full_name='yandex.cloud.loadtesting.agent.v1.Trail.Intervals.to', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='yandex.cloud.loadtesting.agent.v1.Trail.Intervals.count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=872,
  serialized_end=910,
)

_TRAIL = _descriptor.Descriptor(
  name='Trail',
  full_name='yandex.cloud.loadtesting.agent.v1.Trail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overall', full_name='yandex.cloud.loadtesting.agent.v1.Trail.overall', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_id', full_name='yandex.cloud.loadtesting.agent.v1.Trail.case_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='yandex.cloud.loadtesting.agent.v1.Trail.time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reqps', full_name='yandex.cloud.loadtesting.agent.v1.Trail.reqps', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resps', full_name='yandex.cloud.loadtesting.agent.v1.Trail.resps', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expect', full_name='yandex.cloud.loadtesting.agent.v1.Trail.expect', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input', full_name='yandex.cloud.loadtesting.agent.v1.Trail.input', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output', full_name='yandex.cloud.loadtesting.agent.v1.Trail.output', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_time', full_name='yandex.cloud.loadtesting.agent.v1.Trail.connect_time', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_time', full_name='yandex.cloud.loadtesting.agent.v1.Trail.send_time', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency', full_name='yandex.cloud.loadtesting.agent.v1.Trail.latency', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receive_time', full_name='yandex.cloud.loadtesting.agent.v1.Trail.receive_time', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threads', full_name='yandex.cloud.loadtesting.agent.v1.Trail.threads', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q50', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q50', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q75', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q75', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q80', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q80', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q85', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q85', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q90', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q90', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q95', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q95', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q98', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q98', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q99', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q99', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q100', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q100', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_codes', full_name='yandex.cloud.loadtesting.agent.v1.Trail.http_codes', index=22,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='net_codes', full_name='yandex.cloud.loadtesting.agent.v1.Trail.net_codes', index=23,
      number=24, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_intervals', full_name='yandex.cloud.loadtesting.agent.v1.Trail.time_intervals', index=24,
      number=25, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRAIL_CODES, _TRAIL_INTERVALS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=274,
  serialized_end=910,
)


_CREATETRAILRESPONSE = _descriptor.Descriptor(
  name='CreateTrailResponse',
  full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trail_id', full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailResponse.trail_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailResponse.code', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=965,
)

_CREATETRAILREQUEST.fields_by_name['data'].message_type = _TRAIL
_TRAIL_CODES.containing_type = _TRAIL
_TRAIL_INTERVALS.containing_type = _TRAIL
_TRAIL.fields_by_name['http_codes'].message_type = _TRAIL_CODES
_TRAIL.fields_by_name['net_codes'].message_type = _TRAIL_CODES
_TRAIL.fields_by_name['time_intervals'].message_type = _TRAIL_INTERVALS
DESCRIPTOR.message_types_by_name['CreateTrailRequest'] = _CREATETRAILREQUEST
DESCRIPTOR.message_types_by_name['Trail'] = _TRAIL
DESCRIPTOR.message_types_by_name['CreateTrailResponse'] = _CREATETRAILRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateTrailRequest = _reflection.GeneratedProtocolMessageType('CreateTrailRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETRAILREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.trail_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.CreateTrailRequest)
  })
_sym_db.RegisterMessage(CreateTrailRequest)

Trail = _reflection.GeneratedProtocolMessageType('Trail', (_message.Message,), {

  'Codes' : _reflection.GeneratedProtocolMessageType('Codes', (_message.Message,), {
    'DESCRIPTOR' : _TRAIL_CODES,
    '__module__' : 'yandex.cloud.loadtesting.agent.v1.trail_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.Trail.Codes)
    })
  ,

  'Intervals' : _reflection.GeneratedProtocolMessageType('Intervals', (_message.Message,), {
    'DESCRIPTOR' : _TRAIL_INTERVALS,
    '__module__' : 'yandex.cloud.loadtesting.agent.v1.trail_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.Trail.Intervals)
    })
  ,
  'DESCRIPTOR' : _TRAIL,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.trail_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.Trail)
  })
_sym_db.RegisterMessage(Trail)
_sym_db.RegisterMessage(Trail.Codes)
_sym_db.RegisterMessage(Trail.Intervals)

CreateTrailResponse = _reflection.GeneratedProtocolMessageType('CreateTrailResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETRAILRESPONSE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.trail_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.CreateTrailResponse)
  })
_sym_db.RegisterMessage(CreateTrailResponse)


DESCRIPTOR._options = None

_TRAILSERVICE = _descriptor.ServiceDescriptor(
  name='TrailService',
  full_name='yandex.cloud.loadtesting.agent.v1.TrailService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=968,
  serialized_end=1145,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.loadtesting.agent.v1.TrailService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATETRAILREQUEST,
    output_type=_CREATETRAILRESPONSE,
    serialized_options=b'\202\323\344\223\002!\"\034/loadtesting/agent/v1/trails:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRAILSERVICE)

DESCRIPTOR.services_by_name['TrailService'] = _TRAILSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/scan_policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/containerregistry/v1/scan_policy.proto',
  package='yandex.cloud.containerregistry.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3yandex/cloud/containerregistry/v1/scan_policy.proto\x12!yandex.cloud.containerregistry.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcf\x01\n\nScanPolicy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bregistry_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12;\n\x05rules\x18\x05 \x01(\x0b\x32,.yandex.cloud.containerregistry.v1.ScanRules\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x64isabled\x18\x07 \x01(\x08\"\x95\x01\n\tScanRules\x12>\n\tpush_rule\x18\x01 \x01(\x0b\x32+.yandex.cloud.containerregistry.v1.PushRule\x12H\n\x0eschedule_rules\x18\x02 \x03(\x0b\x32\x30.yandex.cloud.containerregistry.v1.ScheduledRule\"\x86\x01\n\x08PushRule\x12h\n\x13repository_prefixes\x18\x01 \x03(\tBK\x82\xc8\x31\x02>0\xf2\xc7\x31\x41\\*|[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\"\xc3\x01\n\rScheduledRule\x12h\n\x13repository_prefixes\x18\x01 \x03(\tBK\x82\xc8\x31\x02>0\xf2\xc7\x31\x41\\*|[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*\x12\x36\n\rrescan_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\xe8\xc7\x31\x01\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x42\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_SCANPOLICY = _descriptor.Descriptor(
  name='ScanPolicy',
  full_name='yandex.cloud.containerregistry.v1.ScanPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.containerregistry.v1.ScanPolicy.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='registry_id', full_name='yandex.cloud.containerregistry.v1.ScanPolicy.registry_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.containerregistry.v1.ScanPolicy.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.containerregistry.v1.ScanPolicy.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='yandex.cloud.containerregistry.v1.ScanPolicy.rules', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.containerregistry.v1.ScanPolicy.created_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='yandex.cloud.containerregistry.v1.ScanPolicy.disabled', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=394,
)


_SCANRULES = _descriptor.Descriptor(
  name='ScanRules',
  full_name='yandex.cloud.containerregistry.v1.ScanRules',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='push_rule', full_name='yandex.cloud.containerregistry.v1.ScanRules.push_rule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule_rules', full_name='yandex.cloud.containerregistry.v1.ScanRules.schedule_rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=546,
)


_PUSHRULE = _descriptor.Descriptor(
  name='PushRule',
  full_name='yandex.cloud.containerregistry.v1.PushRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repository_prefixes', full_name='yandex.cloud.containerregistry.v1.PushRule.repository_prefixes', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0\362\3071A\\*|[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='yandex.cloud.containerregistry.v1.PushRule.disabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=549,
  serialized_end=683,
)


_SCHEDULEDRULE = _descriptor.Descriptor(
  name='ScheduledRule',
  full_name='yandex.cloud.containerregistry.v1.ScheduledRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repository_prefixes', full_name='yandex.cloud.containerregistry.v1.ScheduledRule.repository_prefixes', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0\362\3071A\\*|[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rescan_period', full_name='yandex.cloud.containerregistry.v1.ScheduledRule.rescan_period', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='yandex.cloud.containerregistry.v1.ScheduledRule.disabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=686,
  serialized_end=881,
)

_SCANPOLICY.fields_by_name['rules'].message_type = _SCANRULES
_SCANPOLICY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCANRULES.fields_by_name['push_rule'].message_type = _PUSHRULE
_SCANRULES.fields_by_name['schedule_rules'].message_type = _SCHEDULEDRULE
_SCHEDULEDRULE.fields_by_name['rescan_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['ScanPolicy'] = _SCANPOLICY
DESCRIPTOR.message_types_by_name['ScanRules'] = _SCANRULES
DESCRIPTOR.message_types_by_name['PushRule'] = _PUSHRULE
DESCRIPTOR.message_types_by_name['ScheduledRule'] = _SCHEDULEDRULE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScanPolicy = _reflection.GeneratedProtocolMessageType('ScanPolicy', (_message.Message,), {
  'DESCRIPTOR' : _SCANPOLICY,
  '__module__' : 'yandex.cloud.containerregistry.v1.scan_policy_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ScanPolicy)
  })
_sym_db.RegisterMessage(ScanPolicy)

ScanRules = _reflection.GeneratedProtocolMessageType('ScanRules', (_message.Message,), {
  'DESCRIPTOR' : _SCANRULES,
  '__module__' : 'yandex.cloud.containerregistry.v1.scan_policy_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ScanRules)
  })
_sym_db.RegisterMessage(ScanRules)

PushRule = _reflection.GeneratedProtocolMessageType('PushRule', (_message.Message,), {
  'DESCRIPTOR' : _PUSHRULE,
  '__module__' : 'yandex.cloud.containerregistry.v1.scan_policy_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.PushRule)
  })
_sym_db.RegisterMessage(PushRule)

ScheduledRule = _reflection.GeneratedProtocolMessageType('ScheduledRule', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEDRULE,
  '__module__' : 'yandex.cloud.containerregistry.v1.scan_policy_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ScheduledRule)
  })
_sym_db.RegisterMessage(ScheduledRule)


DESCRIPTOR._options = None
_PUSHRULE.fields_by_name['repository_prefixes']._options = None
_SCHEDULEDRULE.fields_by_name['repository_prefixes']._options = None
_SCHEDULEDRULE.fields_by_name['rescan_period']._options = None
# @@protoc_insertion_point(module_scope)
